@@ -25,7 +25,6 @@ class WP_Terms_List_Table extends WP_List_Table {
 	 * Constructor.
 	 *
 	 * @since 3.1.0
-	 * @access public
 	 *
 	 * @see WP_List_Table::__construct() for more information on default arguments.
 	 *
@@ -39,32 +38,36 @@ class WP_Terms_List_Table extends WP_List_Table {
 	public function __construct( $args = array() ) {
 		global $post_type, $taxonomy, $action, $tax;
 
-		parent::__construct( array(
-			'plural' => 'tags',
-			'singular' => 'tag',
-			'screen' => isset( $args['screen'] ) ? $args['screen'] : null,
-		) );
+		parent::__construct(
+			array(
+				'plural'   => 'tags',
+				'singular' => 'tag',
+				'screen'   => isset( $args['screen'] ) ? $args['screen'] : null,
+			)
+		);
 
 		$action    = $this->screen->action;
 		$post_type = $this->screen->post_type;
 		$taxonomy  = $this->screen->taxonomy;
 
-		if ( empty( $taxonomy ) )
+		if ( empty( $taxonomy ) ) {
 			$taxonomy = 'post_tag';
+		}
 
-		if ( ! taxonomy_exists( $taxonomy ) )
+		if ( ! taxonomy_exists( $taxonomy ) ) {
 			wp_die( __( 'Invalid taxonomy.' ) );
+		}
 
 		$tax = get_taxonomy( $taxonomy );
 
 		// @todo Still needed? Maybe just the show_ui part.
-		if ( empty( $post_type ) || !in_array( $post_type, get_post_types( array( 'show_ui' => true ) ) ) )
+		if ( empty( $post_type ) || ! in_array( $post_type, get_post_types( array( 'show_ui' => true ) ), true ) ) {
 			$post_type = 'post';
+		}
 
 	}
 
 	/**
-	 *
 	 * @return bool
 	 */
 	public function ajax_user_can() {
@@ -72,12 +75,13 @@ class WP_Terms_List_Table extends WP_List_Table {
 	}
 
 	/**
-	 * @access public
 	 */
 	public function prepare_items() {
-		$tags_per_page = $this->get_items_per_page( 'edit_' . $this->screen->taxonomy . '_per_page' );
+		$taxonomy = $this->screen->taxonomy;
 
-		if ( 'post_tag' === $this->screen->taxonomy ) {
+		$tags_per_page = $this->get_items_per_page( "edit_{$taxonomy}_per_page" );
+
+		if ( 'post_tag' === $taxonomy ) {
 			/**
 			 * Filters the number of terms displayed per page for the Tags list table.
 			 *
@@ -91,12 +95,12 @@ class WP_Terms_List_Table extends WP_List_Table {
 			 * Filters the number of terms displayed per page for the Tags list table.
 			 *
 			 * @since 2.7.0
-			 * @deprecated 2.8.0 Use edit_tags_per_page instead.
+			 * @deprecated 2.8.0 Use {@see 'edit_tags_per_page'} instead.
 			 *
 			 * @param int $tags_per_page Number of tags to be displayed. Default 20.
 			 */
-			$tags_per_page = apply_filters( 'tagsperpage', $tags_per_page );
-		} elseif ( 'category' === $this->screen->taxonomy ) {
+			$tags_per_page = apply_filters_deprecated( 'tagsperpage', array( $tags_per_page ), '2.8.0', 'edit_tags_per_page' );
+		} elseif ( 'category' === $taxonomy ) {
 			/**
 			 * Filters the number of terms displayed per page for the Categories list table.
 			 *
@@ -107,46 +111,57 @@ class WP_Terms_List_Table extends WP_List_Table {
 			$tags_per_page = apply_filters( 'edit_categories_per_page', $tags_per_page );
 		}
 
-		$search = !empty( $_REQUEST['s'] ) ? trim( wp_unslash( $_REQUEST['s'] ) ) : '';
+		$search = ! empty( $_REQUEST['s'] ) ? trim( wp_unslash( $_REQUEST['s'] ) ) : '';
 
 		$args = array(
-			'search' => $search,
-			'page' => $this->get_pagenum(),
-			'number' => $tags_per_page,
+			'taxonomy'   => $taxonomy,
+			'search'     => $search,
+			'page'       => $this->get_pagenum(),
+			'number'     => $tags_per_page,
+			'hide_empty' => 0,
 		);
 
-		if ( !empty( $_REQUEST['orderby'] ) )
+		if ( ! empty( $_REQUEST['orderby'] ) ) {
 			$args['orderby'] = trim( wp_unslash( $_REQUEST['orderby'] ) );
+		}
 
-		if ( !empty( $_REQUEST['order'] ) )
+		if ( ! empty( $_REQUEST['order'] ) ) {
 			$args['order'] = trim( wp_unslash( $_REQUEST['order'] ) );
+		}
 
+		$args['offset'] = ( $args['page'] - 1 ) * $args['number'];
+
+		// Save the values because 'number' and 'offset' can be subsequently overridden.
 		$this->callback_args = $args;
 
-		$this->set_pagination_args( array(
-			'total_items' => wp_count_terms( $this->screen->taxonomy, compact( 'search' ) ),
-			'per_page' => $tags_per_page,
-		) );
+		if ( is_taxonomy_hierarchical( $taxonomy ) && ! isset( $args['orderby'] ) ) {
+			// We'll need the full set of terms then.
+			$args['number'] = 0;
+			$args['offset'] = $args['number'];
+		}
+
+		$this->items = get_terms( $args );
+
+		$this->set_pagination_args(
+			array(
+				'total_items' => wp_count_terms(
+					array(
+						'taxonomy' => $taxonomy,
+						'search'   => $search,
+					)
+				),
+				'per_page'    => $tags_per_page,
+			)
+		);
 	}
 
 	/**
-	 *
-	 * @return bool
-	 */
-	public function has_items() {
-		// todo: populate $this->items in prepare_items()
-		return true;
-	}
-
-	/**
-	 * @access public
 	 */
 	public function no_items() {
 		echo get_taxonomy( $this->screen->taxonomy )->labels->not_found;
 	}
 
 	/**
-	 *
 	 * @return array
 	 */
 	protected function get_bulk_actions() {
@@ -160,18 +175,17 @@ class WP_Terms_List_Table extends WP_List_Table {
 	}
 
 	/**
-	 *
 	 * @return string
 	 */
 	public function current_action() {
-		if ( isset( $_REQUEST['action'] ) && isset( $_REQUEST['delete_tags'] ) && ( 'delete' === $_REQUEST['action'] || 'delete' === $_REQUEST['action2'] ) )
+		if ( isset( $_REQUEST['action'] ) && isset( $_REQUEST['delete_tags'] ) && 'delete' === $_REQUEST['action'] ) {
 			return 'bulk-delete';
+		}
 
 		return parent::current_action();
 	}
 
 	/**
-	 *
 	 * @return array
 	 */
 	public function get_columns() {
@@ -192,7 +206,6 @@ class WP_Terms_List_Table extends WP_List_Table {
 	}
 
 	/**
-	 *
 	 * @return array
 	 */
 	protected function get_sortable_columns() {
@@ -201,56 +214,42 @@ class WP_Terms_List_Table extends WP_List_Table {
 			'description' => 'description',
 			'slug'        => 'slug',
 			'posts'       => 'count',
-			'links'       => 'count'
+			'links'       => 'count',
 		);
 	}
 
 	/**
-	 * @access public
 	 */
 	public function display_rows_or_placeholder() {
 		$taxonomy = $this->screen->taxonomy;
 
-		$args = wp_parse_args( $this->callback_args, array(
-			'page' => 1,
-			'number' => 20,
-			'search' => '',
-			'hide_empty' => 0
-		) );
-
-		$page = $args['page'];
-
-		// Set variable because $args['number'] can be subsequently overridden.
-		$number = $args['number'];
-
-		$args['offset'] = $offset = ( $page - 1 ) * $number;
+		$number = $this->callback_args['number'];
+		$offset = $this->callback_args['offset'];
 
 		// Convert it to table rows.
 		$count = 0;
 
-		if ( is_taxonomy_hierarchical( $taxonomy ) && ! isset( $args['orderby'] ) ) {
-			// We'll need the full set of terms then.
-			$args['number'] = $args['offset'] = 0;
-		}
-		$terms = get_terms( $taxonomy, $args );
-
-		if ( empty( $terms ) || ! is_array( $terms ) ) {
+		if ( empty( $this->items ) || ! is_array( $this->items ) ) {
 			echo '<tr class="no-items"><td class="colspanchange" colspan="' . $this->get_column_count() . '">';
 			$this->no_items();
 			echo '</td></tr>';
 			return;
 		}
 
-		if ( is_taxonomy_hierarchical( $taxonomy ) && ! isset( $args['orderby'] ) ) {
-			if ( ! empty( $args['search'] ) ) {// Ignore children on searches.
+		if ( is_taxonomy_hierarchical( $taxonomy ) && ! isset( $this->callback_args['orderby'] ) ) {
+			if ( ! empty( $this->callback_args['search'] ) ) {// Ignore children on searches.
 				$children = array();
 			} else {
 				$children = _get_term_hierarchy( $taxonomy );
 			}
-			// Some funky recursion to get the job done( Paging & parents mainly ) is contained within, Skip it for non-hierarchical taxonomies for performance sake
-			$this->_rows( $taxonomy, $terms, $children, $offset, $number, $count );
+
+			/*
+			 * Some funky recursion to get the job done (paging & parents mainly) is contained within.
+			 * Skip it for non-hierarchical taxonomies for performance sake.
+			 */
+			$this->_rows( $taxonomy, $this->items, $children, $offset, $number, $count );
 		} else {
-			foreach ( $terms as $term ) {
+			foreach ( $this->items as $term ) {
 				$this->single_row( $term );
 			}
 		}
@@ -258,13 +257,13 @@ class WP_Terms_List_Table extends WP_List_Table {
 
 	/**
 	 * @param string $taxonomy
-	 * @param array $terms
-	 * @param array $children
-	 * @param int   $start
-	 * @param int   $per_page
-	 * @param int   $count
-	 * @param int   $parent
-	 * @param int   $level
+	 * @param array  $terms
+	 * @param array  $children
+	 * @param int    $start
+	 * @param int    $per_page
+	 * @param int    $count
+	 * @param int    $parent
+	 * @param int    $level
 	 */
 	private function _rows( $taxonomy, $terms, &$children, $start, $per_page, &$count, $parent = 0, $level = 0 ) {
 
@@ -272,27 +271,36 @@ class WP_Terms_List_Table extends WP_List_Table {
 
 		foreach ( $terms as $key => $term ) {
 
-			if ( $count >= $end )
+			if ( $count >= $end ) {
 				break;
+			}
 
-			if ( $term->parent != $parent && empty( $_REQUEST['s'] ) )
+			if ( $term->parent !== $parent && empty( $_REQUEST['s'] ) ) {
 				continue;
+			}
 
 			// If the page starts in a subtree, print the parents.
-			if ( $count == $start && $term->parent > 0 && empty( $_REQUEST['s'] ) ) {
-				$my_parents = $parent_ids = array();
-				$p = $term->parent;
+			if ( $count === $start && $term->parent > 0 && empty( $_REQUEST['s'] ) ) {
+				$my_parents = array();
+				$parent_ids = array();
+				$p          = $term->parent;
+
 				while ( $p ) {
-					$my_parent = get_term( $p, $taxonomy );
+					$my_parent    = get_term( $p, $taxonomy );
 					$my_parents[] = $my_parent;
-					$p = $my_parent->parent;
-					if ( in_array( $p, $parent_ids ) ) // Prevent parent loops.
+					$p            = $my_parent->parent;
+
+					if ( in_array( $p, $parent_ids, true ) ) { // Prevent parent loops.
 						break;
+					}
+
 					$parent_ids[] = $p;
 				}
+
 				unset( $parent_ids );
 
 				$num_parents = count( $my_parents );
+
 				while ( $my_parent = array_pop( $my_parents ) ) {
 					echo "\t";
 					$this->single_row( $my_parent, $level - $num_parents );
@@ -307,37 +315,55 @@ class WP_Terms_List_Table extends WP_List_Table {
 
 			++$count;
 
-			unset( $terms[$key] );
+			unset( $terms[ $key ] );
 
-			if ( isset( $children[$term->term_id] ) && empty( $_REQUEST['s'] ) )
+			if ( isset( $children[ $term->term_id ] ) && empty( $_REQUEST['s'] ) ) {
 				$this->_rows( $taxonomy, $terms, $children, $start, $per_page, $count, $term->term_id, $level + 1 );
+			}
 		}
 	}
 
 	/**
 	 * @global string $taxonomy
-	 * @param WP_Term $tag Term object.
-	 * @param int $level
+	 * @param WP_Term $tag   Term object.
+	 * @param int     $level
 	 */
 	public function single_row( $tag, $level = 0 ) {
 		global $taxonomy;
- 		$tag = sanitize_term( $tag, $taxonomy );
+		$tag = sanitize_term( $tag, $taxonomy );
 
 		$this->level = $level;
 
-		echo '<tr id="tag-' . $tag->term_id . '">';
+		if ( $tag->parent ) {
+			$count = count( get_ancestors( $tag->term_id, $taxonomy, 'taxonomy' ) );
+			$level = 'level-' . $count;
+		} else {
+			$level = 'level-0';
+		}
+
+		echo '<tr id="tag-' . $tag->term_id . '" class="' . $level . '">';
 		$this->single_row_columns( $tag );
 		echo '</tr>';
 	}
 
 	/**
-	 * @param WP_Term $tag Term object.
+	 * @since 5.9.0 Renamed `$tag` to `$item` to match parent class for PHP 8 named parameter support.
+	 *
+	 * @param WP_Term $item Term object.
 	 * @return string
 	 */
-	public function column_cb( $tag ) {
+	public function column_cb( $item ) {
+		// Restores the more descriptive, specific name for use within this method.
+		$tag = $item;
+
 		if ( current_user_can( 'delete_term', $tag->term_id ) ) {
-			return '<label class="screen-reader-text" for="cb-select-' . $tag->term_id . '">' . sprintf( __( 'Select %s' ), $tag->name ) . '</label>'
-				. '<input type="checkbox" name="delete_tags[]" value="' . $tag->term_id . '" id="cb-select-' . $tag->term_id . '" />';
+			return sprintf(
+				'<label class="screen-reader-text" for="cb-select-%1$s">%2$s</label>' .
+				'<input type="checkbox" name="delete_tags[]" value="%1$s" id="cb-select-%1$s" />',
+				$tag->term_id,
+				/* translators: %s: Taxonomy term name. */
+				sprintf( __( 'Select %s' ), $tag->name )
+			);
 		}
 
 		return '&nbsp;';
@@ -371,17 +397,25 @@ class WP_Terms_List_Table extends WP_List_Table {
 
 		$uri = wp_doing_ajax() ? wp_get_referer() : $_SERVER['REQUEST_URI'];
 
-		$edit_link = add_query_arg(
-			'wp_http_referer',
-			urlencode( wp_unslash( $uri ) ),
-			get_edit_term_link( $tag->term_id, $taxonomy, $this->screen->post_type )
-		);
+		$edit_link = get_edit_term_link( $tag, $taxonomy, $this->screen->post_type );
+
+		if ( $edit_link ) {
+			$edit_link = add_query_arg(
+				'wp_http_referer',
+				urlencode( wp_unslash( $uri ) ),
+				$edit_link
+			);
+			$name      = sprintf(
+				'<a class="row-title" href="%s" aria-label="%s">%s</a>',
+				esc_url( $edit_link ),
+				/* translators: %s: Taxonomy term name. */
+				esc_attr( sprintf( __( '&#8220;%s&#8221; (Edit)' ), $tag->name ) ),
+				$name
+			);
+		}
 
 		$out = sprintf(
-			'<strong><a class="row-title" href="%s" aria-label="%s">%s</a></strong><br />',
-			esc_url( $edit_link ),
-			/* translators: %s: taxonomy term name */
-			esc_attr( sprintf( __( '&#8220;%s&#8221; (Edit)' ), $tag->name ) ),
+			'<strong>%s</strong><br />',
 			$name
 		);
 
@@ -399,7 +433,6 @@ class WP_Terms_List_Table extends WP_List_Table {
 	 * Gets the name of the default primary column.
 	 *
 	 * @since 4.3.0
-	 * @access protected
 	 *
 	 * @return string Name of the default primary column, in this case, 'name'.
 	 */
@@ -411,58 +444,64 @@ class WP_Terms_List_Table extends WP_List_Table {
 	 * Generates and displays row action links.
 	 *
 	 * @since 4.3.0
-	 * @access protected
+	 * @since 5.9.0 Renamed `$tag` to `$item` to match parent class for PHP 8 named parameter support.
 	 *
-	 * @param WP_Term $tag         Tag being acted upon.
+	 * @param WP_Term $item        Tag being acted upon.
 	 * @param string  $column_name Current column name.
 	 * @param string  $primary     Primary column name.
-	 * @return string Row actions output for terms.
+	 * @return string Row actions output for terms, or an empty string
+	 *                if the current column is not the primary column.
 	 */
-	protected function handle_row_actions( $tag, $column_name, $primary ) {
+	protected function handle_row_actions( $item, $column_name, $primary ) {
 		if ( $primary !== $column_name ) {
 			return '';
 		}
 
+		// Restores the more descriptive, specific name for use within this method.
+		$tag      = $item;
 		$taxonomy = $this->screen->taxonomy;
-		$tax = get_taxonomy( $taxonomy );
-		$uri = wp_doing_ajax() ? wp_get_referer() : $_SERVER['REQUEST_URI'];
+		$tax      = get_taxonomy( $taxonomy );
+		$uri      = wp_doing_ajax() ? wp_get_referer() : $_SERVER['REQUEST_URI'];
 
 		$edit_link = add_query_arg(
 			'wp_http_referer',
 			urlencode( wp_unslash( $uri ) ),
-			get_edit_term_link( $tag->term_id, $taxonomy, $this->screen->post_type )
+			get_edit_term_link( $tag, $taxonomy, $this->screen->post_type )
 		);
 
 		$actions = array();
+
 		if ( current_user_can( 'edit_term', $tag->term_id ) ) {
 			$actions['edit'] = sprintf(
 				'<a href="%s" aria-label="%s">%s</a>',
 				esc_url( $edit_link ),
-				/* translators: %s: taxonomy term name */
+				/* translators: %s: Taxonomy term name. */
 				esc_attr( sprintf( __( 'Edit &#8220;%s&#8221;' ), $tag->name ) ),
 				__( 'Edit' )
 			);
 			$actions['inline hide-if-no-js'] = sprintf(
-				'<a href="#" class="editinline aria-button-if-js" aria-label="%s">%s</a>',
-				/* translators: %s: taxonomy term name */
+				'<button type="button" class="button-link editinline" aria-label="%s" aria-expanded="false">%s</button>',
+				/* translators: %s: Taxonomy term name. */
 				esc_attr( sprintf( __( 'Quick edit &#8220;%s&#8221; inline' ), $tag->name ) ),
 				__( 'Quick&nbsp;Edit' )
 			);
 		}
+
 		if ( current_user_can( 'delete_term', $tag->term_id ) ) {
 			$actions['delete'] = sprintf(
 				'<a href="%s" class="delete-tag aria-button-if-js" aria-label="%s">%s</a>',
 				wp_nonce_url( "edit-tags.php?action=delete&amp;taxonomy=$taxonomy&amp;tag_ID=$tag->term_id", 'delete-tag_' . $tag->term_id ),
-				/* translators: %s: taxonomy term name */
+				/* translators: %s: Taxonomy term name. */
 				esc_attr( sprintf( __( 'Delete &#8220;%s&#8221;' ), $tag->name ) ),
 				__( 'Delete' )
 			);
 		}
-		if ( $tax->public ) {
+
+		if ( is_taxonomy_viewable( $tax ) ) {
 			$actions['view'] = sprintf(
 				'<a href="%s" aria-label="%s">%s</a>',
 				get_term_link( $tag ),
-				/* translators: %s: taxonomy term name */
+				/* translators: %s: Taxonomy term name. */
 				esc_attr( sprintf( __( 'View &#8220;%s&#8221; archive' ), $tag->name ) ),
 				__( 'View' )
 			);
@@ -472,11 +511,12 @@ class WP_Terms_List_Table extends WP_List_Table {
 		 * Filters the action links displayed for each term in the Tags list table.
 		 *
 		 * @since 2.8.0
-		 * @deprecated 3.0.0 Use {$taxonomy}_row_actions instead.
+		 * @since 3.0.0 Deprecated in favor of {@see '{$taxonomy}_row_actions'} filter.
+		 * @since 5.4.2 Restored (un-deprecated).
 		 *
-		 * @param array  $actions An array of action links to be displayed. Default
-		 *                        'Edit', 'Quick Edit', 'Delete', and 'View'.
-		 * @param WP_Term $tag    Term object.
+		 * @param string[] $actions An array of action links to be displayed. Default
+		 *                          'Edit', 'Quick Edit', 'Delete', and 'View'.
+		 * @param WP_Term  $tag     Term object.
 		 */
 		$actions = apply_filters( 'tag_row_actions', $actions, $tag );
 
@@ -485,11 +525,16 @@ class WP_Terms_List_Table extends WP_List_Table {
 		 *
 		 * The dynamic portion of the hook name, `$taxonomy`, refers to the taxonomy slug.
 		 *
+		 * Possible hook names include:
+		 *
+		 *  - `category_row_actions`
+		 *  - `post_tag_row_actions`
+		 *
 		 * @since 3.0.0
 		 *
-		 * @param array  $actions An array of action links to be displayed. Default
-		 *                        'Edit', 'Quick Edit', 'Delete', and 'View'.
-		 * @param WP_Term $tag    Term object.
+		 * @param string[] $actions An array of action links to be displayed. Default
+		 *                          'Edit', 'Quick Edit', 'Delete', and 'View'.
+		 * @param WP_Term  $tag     Term object.
 		 */
 		$actions = apply_filters( "{$taxonomy}_row_actions", $actions, $tag );
 
@@ -501,7 +546,11 @@ class WP_Terms_List_Table extends WP_List_Table {
 	 * @return string
 	 */
 	public function column_description( $tag ) {
-		return $tag->description;
+		if ( $tag->description ) {
+			return $tag->description;
+		} else {
+			return '<span aria-hidden="true">&#8212;</span><span class="screen-reader-text">' . __( 'No description' ) . '</span>';
+		}
 	}
 
 	/**
@@ -523,22 +572,28 @@ class WP_Terms_List_Table extends WP_List_Table {
 		$tax = get_taxonomy( $this->screen->taxonomy );
 
 		$ptype_object = get_post_type_object( $this->screen->post_type );
-		if ( ! $ptype_object->show_ui )
+		if ( ! $ptype_object->show_ui ) {
 			return $count;
+		}
 
 		if ( $tax->query_var ) {
 			$args = array( $tax->query_var => $tag->slug );
 		} else {
-			$args = array( 'taxonomy' => $tax->name, 'term' => $tag->slug );
+			$args = array(
+				'taxonomy' => $tax->name,
+				'term'     => $tag->slug,
+			);
 		}
 
-		if ( 'post' != $this->screen->post_type )
+		if ( 'post' !== $this->screen->post_type ) {
 			$args['post_type'] = $this->screen->post_type;
+		}
 
-		if ( 'attachment' === $this->screen->post_type )
-			return "<a href='" . esc_url ( add_query_arg( $args, 'upload.php' ) ) . "'>$count</a>";
+		if ( 'attachment' === $this->screen->post_type ) {
+			return "<a href='" . esc_url( add_query_arg( $args, 'upload.php' ) ) . "'>$count</a>";
+		}
 
-		return "<a href='" . esc_url ( add_query_arg( $args, 'edit.php' ) ) . "'>$count</a>";
+		return "<a href='" . esc_url( add_query_arg( $args, 'edit.php' ) ) . "'>$count</a>";
 	}
 
 	/**
@@ -547,30 +602,40 @@ class WP_Terms_List_Table extends WP_List_Table {
 	 */
 	public function column_links( $tag ) {
 		$count = number_format_i18n( $tag->count );
-		if ( $count )
+
+		if ( $count ) {
 			$count = "<a href='link-manager.php?cat_id=$tag->term_id'>$count</a>";
+		}
+
 		return $count;
 	}
 
 	/**
-	 * @param WP_Term $tag Term object.
-	 * @param string $column_name
+	 * @since 5.9.0 Renamed `$tag` to `$item` to match parent class for PHP 8 named parameter support.
+	 *
+	 * @param WP_Term $item        Term object.
+	 * @param string  $column_name Name of the column.
 	 * @return string
 	 */
-	public function column_default( $tag, $column_name ) {
+	public function column_default( $item, $column_name ) {
 		/**
 		 * Filters the displayed columns in the terms list table.
 		 *
 		 * The dynamic portion of the hook name, `$this->screen->taxonomy`,
 		 * refers to the slug of the current taxonomy.
 		 *
+		 * Possible hook names include:
+		 *
+		 *  - `manage_category_custom_column`
+		 *  - `manage_post_tag_custom_column`
+		 *
 		 * @since 2.8.0
 		 *
-		 * @param string $string      Blank string.
+		 * @param string $string      Custom column output. Default empty.
 		 * @param string $column_name Name of the column.
 		 * @param int    $term_id     Term ID.
 		 */
-		return apply_filters( "manage_{$this->screen->taxonomy}_custom_column", '', $column_name, $tag->term_id );
+		return apply_filters( "manage_{$this->screen->taxonomy}_custom_column", '', $column_name, $item->term_id );
 	}
 
 	/**
@@ -581,12 +646,16 @@ class WP_Terms_List_Table extends WP_List_Table {
 	public function inline_edit() {
 		$tax = get_taxonomy( $this->screen->taxonomy );
 
-		if ( ! current_user_can( $tax->cap->edit_terms ) )
+		if ( ! current_user_can( $tax->cap->edit_terms ) ) {
 			return;
-?>
+		}
+		?>
 
-	<form method="get"><table style="display: none"><tbody id="inlineedit">
-		<tr id="inline-edit" class="inline-edit-row" style="display: none"><td colspan="<?php echo $this->get_column_count(); ?>" class="colspanchange">
+		<form method="get">
+		<table style="display: none"><tbody id="inlineedit">
+
+			<tr id="inline-edit" class="inline-edit-row" style="display: none">
+			<td colspan="<?php echo $this->get_column_count(); ?>" class="colspanchange">
 
 			<fieldset>
 				<legend class="inline-edit-legend"><?php _e( 'Quick Edit' ); ?></legend>
@@ -595,41 +664,56 @@ class WP_Terms_List_Table extends WP_List_Table {
 					<span class="title"><?php _ex( 'Name', 'term name' ); ?></span>
 					<span class="input-text-wrap"><input type="text" name="name" class="ptitle" value="" /></span>
 				</label>
-	<?php if ( !global_terms_enabled() ) { ?>
-				<label>
-					<span class="title"><?php _e( 'Slug' ); ?></span>
-					<span class="input-text-wrap"><input type="text" name="slug" class="ptitle" value="" /></span>
-				</label>
-	<?php } ?>
-			</div></fieldset>
-	<?php
 
-		$core_columns = array( 'cb' => true, 'description' => true, 'name' => true, 'slug' => true, 'posts' => true );
+				<?php if ( ! global_terms_enabled() ) : ?>
+					<label>
+						<span class="title"><?php _e( 'Slug' ); ?></span>
+						<span class="input-text-wrap"><input type="text" name="slug" class="ptitle" value="" /></span>
+					</label>
+				<?php endif; ?>
+				</div>
+			</fieldset>
 
-		list( $columns ) = $this->get_column_info();
+			<?php
+			$core_columns = array(
+				'cb'          => true,
+				'description' => true,
+				'name'        => true,
+				'slug'        => true,
+				'posts'       => true,
+			);
 
-		foreach ( $columns as $column_name => $column_display_name ) {
-			if ( isset( $core_columns[$column_name] ) )
-				continue;
+			list( $columns ) = $this->get_column_info();
 
-			/** This action is documented in wp-admin/includes/class-wp-posts-list-table.php */
-			do_action( 'quick_edit_custom_box', $column_name, 'edit-tags', $this->screen->taxonomy );
-		}
+			foreach ( $columns as $column_name => $column_display_name ) {
+				if ( isset( $core_columns[ $column_name ] ) ) {
+					continue;
+				}
 
-	?>
+				/** This action is documented in wp-admin/includes/class-wp-posts-list-table.php */
+				do_action( 'quick_edit_custom_box', $column_name, 'edit-tags', $this->screen->taxonomy );
+			}
+			?>
 
-		<p class="inline-edit-save submit">
-			<button type="button" class="cancel button alignleft"><?php _e( 'Cancel' ); ?></button>
-			<button type="button" class="save button button-primary alignright"><?php echo $tax->labels->update_item; ?></button>
-			<span class="spinner"></span>
-			<span class="error" style="display:none;"></span>
-			<?php wp_nonce_field( 'taxinlineeditnonce', '_inline_edit', false ); ?>
-			<input type="hidden" name="taxonomy" value="<?php echo esc_attr( $this->screen->taxonomy ); ?>" />
-			<input type="hidden" name="post_type" value="<?php echo esc_attr( $this->screen->post_type ); ?>" />
-			<br class="clear" />
-		</p>
-		</td></tr>
-		</tbody></table></form>
-	<?php
+			<div class="inline-edit-save submit">
+				<button type="button" class="cancel button alignleft"><?php _e( 'Cancel' ); ?></button>
+				<button type="button" class="save button button-primary alignright"><?php echo $tax->labels->update_item; ?></button>
+				<span class="spinner"></span>
+
+				<?php wp_nonce_field( 'taxinlineeditnonce', '_inline_edit', false ); ?>
+				<input type="hidden" name="taxonomy" value="<?php echo esc_attr( $this->screen->taxonomy ); ?>" />
+				<input type="hidden" name="post_type" value="<?php echo esc_attr( $this->screen->post_type ); ?>" />
+				<br class="clear" />
+
+				<div class="notice notice-error notice-alt inline hidden">
+					<p class="error"></p>
+				</div>
+			</div>
+
+			</td></tr>
+
+		</tbody></table>
+		</form>
+		<?php
 	}
 }
